@@ -1,7 +1,7 @@
-#ifndef GNU_gama_local___language__header_file_h
-#define GNU_gama_local___language__header_file_h
+#ifndef GNU_gama_local_language_header_file_h
+#define GNU_gama_local_language_header_file_h
 
-namespace GNU_gama { namespace local {      /* slovnikar 1.12 */
+namespace GNU_gama { namespace local {      /* slovnikar 1.14 */
 
 enum gama_language { en, ca, cz, du, es, fi, fr, hu, ru, ua, zh };
 void set_gama_language(gama_language);
