@@ -1,3 +1,23 @@
+/*
+  GNU Gama C++ library tests/matvec
+  Copyright (C) 2017  Ales Cepek <cepek@gnu.org>
+
+  This file is part of the GNU Gama C++ library tests/matvec
+  
+  GNU Gama is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
+  
+  GNU Gama is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with GNU Gama.  If not, see <http://www.gnu.org/licenses/>.
+*/
+
 #include <matvec/matvec.h>
 #include <matvec/svd.h>
 #include <iostream>
